@@ -1,8 +1,11 @@
 package Moonshine::Bootstrap;
 
-use 5.006;
-use strict;
-use warnings;
+1;
+
+__END__
+
+=cut
+
 
 =head1 NAME
 
@@ -10,11 +13,11 @@ Moonshine::Bootstrap - Shine.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 AUTHOR
 
